@@ -3,7 +3,10 @@
 # └─────────────────────────────────────────────────────────────────────────────────────
 
 from pyob.mixins.ob_dunder import ObDunderMixin
-from pyob.mixins.ob_label import ObLabelMixin, ObMetaLabelMixin
+from pyob.mixins.ob_label import ObLabelMixin
+from pyob.mixins.ob_meta_label import ObMetaLabelMixin
 from pyob.mixins.ob_set_dunder import ObSetDunderMixin
 from pyob.mixins.ob_set_label import ObSetLabelMixin
 from pyob.mixins.ob_set_method import ObSetMethodMixin
+from pyob.mixins.ob_store_dunder import ObStoreDunderMixin
+from pyob.mixins.ob_store_method import ObStoreMethodMixin
