@@ -8,7 +8,6 @@ from pyob.exceptions import (
     UnrelatedObjectsError,
 )
 from pyob.tools import (
-    convert_obs_dict_to_list,
     filter_by_key,
     filter_by_keys,
     is_iterable,
@@ -181,7 +180,7 @@ class ObSetDunderMixin:
 
         # Resolve potential keys
         other_keys = filter_by_keys(
-            self._obs, self._keys, other_keys, ob_label_plural=self.ob_label_plural
+            self._obs, self._Ob._keys, other_keys, ob_label_plural=self.ob_label_plural
         )
 
         # Combine resolved objects
@@ -210,7 +209,7 @@ class ObSetDunderMixin:
         # Return whether item or key in objects
         return (item in self._obs) or len(
             filter_by_key(
-                self._obs, self._keys, item, ob_label_plural=self.ob_label_plural
+                self._obs, self._Ob._keys, item, ob_label_plural=self.ob_label_plural
             )
         ) > 0
 
@@ -257,7 +256,7 @@ class ObSetDunderMixin:
         """ Get Item Method """
 
         # Get objects as list
-        _obs = convert_obs_dict_to_list(self._obs)
+        _obs = list(self)
 
         # Check if key is a slice
         if isinstance(key, slice):
@@ -275,8 +274,14 @@ class ObSetDunderMixin:
     def __iter__(self):
         """ Iterate Method """
 
-        # Return objects
-        return iter(self._obs)
+        # Iterate over objects in object set
+        for _ob, count in self._obs.items():
+
+            # Iterate over object count
+            for _ in range(count):
+
+                # Yield object
+                yield _ob
 
     # ┌─────────────────────────────────────────────────────────────────────────────────
     # │ __LEN__
@@ -286,7 +291,7 @@ class ObSetDunderMixin:
         """ Length Method """
 
         # Return length of objects
-        return len(self._obs)
+        return sum(self._obs.values())
 
     # ┌─────────────────────────────────────────────────────────────────────────────────
     # │ __OR__
@@ -320,20 +325,26 @@ class ObSetDunderMixin:
     def __repr__(self):
         """ Representation Method """
 
+        # Define threshold
+        threshold = 20
+
+        # Get object count
+        _ob_count = len(self)
+
         # Initialize representation as object set name
         representation = self.name
 
         # Add count to representation
-        representation += f": {self.count()}"
+        representation += f": {_ob_count}"
 
         # Get the first 20 objects
-        _obs = convert_obs_dict_to_list(self._obs)[:20]
+        _obs = list(self)[:threshold]
 
         # Stringify objects according to object set class string field
         _obs = [_ob.__repr__(_str=self._Ob._str) for _ob in _obs]
 
         # Check if there are more than n objects total
-        if len(self) > len(_obs):
+        if _ob_count > threshold:
 
             # Add truncation message to objects list
             _obs.append("...(remaining elements truncated)... ")
